# BEGIN SourceDeps(oneline):
BuildRequires: /usr/bin/Xvfb /usr/bin/epydoc /usr/bin/pychecker
# END SourceDeps(oneline)
%define         gst_minver      0.10.11
%define         gstpb_minver    0.10.11
%define         gstpy_minver    0.10.4
%define         pygtk_minver    2.10.0
%define         kiwi_minver     1.9.13

%define         gstreamer       gstreamer

Name:           flumotion
Version:        0.10.0
Release:        alt1_6
Summary:        Streaming Server based on GStreamer and Twisted

Group:          Networking/WWW
License:        LGPLv2
URL:            http://www.flumotion.net/
Source0:         http://www.flumotion.net/src/flumotion/%{name}-%{version}.tar.bz2
Source1:	flumotion.service

Requires:       %{gstreamer} >= %{gst_minver}
Requires:       gst-plugins-base >= %{gstpb_minver}
Requires:       pygtk2 >= %{pygtk_minver}
# For triggerun

# for make-dummy-cert to work
Requires(post): openssl

BuildRequires:  %{gstreamer}-devel >= %{gst_minver}
BuildRequires:  python-module-gst >= %{gstpy_minver}
BuildRequires: python-module-twisted-core python-module-twisted-core-gui python-module-twisted-core-gui-gnome python-module-twisted-core-gui-tk python-module-twisted-core-gui-wx
BuildRequires:  python-module-twisted-names
BuildRequires:  python-module-twisted-web
BuildRequires:  python-devel
BuildRequires:  python-module-pygtk-devel
BuildRequires:  gtk2-devel
BuildRequires:  python-module-kiwi >= %{kiwi_minver}

# docs
BuildRequires:  python-module-epydoc
BuildRequires:  xorg-x11-xvfb

# sigh, libtool
BuildRequires:  gcc-c++

BuildRequires:  desktop-file-utils

# even though intltool is included, this dependency pulls in perl(XML::Parser)
# which is needed at configure time.
BuildRequires:  gettext
BuildRequires:  intltool
Source44: import.info

# since we compile pytrayicon, we're no longer noarch
# BuildArch:    noarch

%description
Flumotion is a GPL streaming media server written in Python. It is distributed
and component-based: every step in the streaming process (production,
conversion, consumption) can be run inside a separate process on separate
machines.

Flumotion uses Twisted and GStreamer. Twisted enables the high-level
functionality, distributing components over the network. GStreamer, through the
Python bindings, enables the high-speed low-level functionality: actual media
processing.

Flumotion uses a central manager process to control the complete network; one
or more worker processes distributed over machines to run actual streaming
components; and one or more admin clients connecting to the manager to control
it.

%prep
%setup -q

%build
%configure

make EPYDOC_ARGS"= -q --no-frames --html"

%install

# use DESTDIR so compiled python files get tagged correctly with their
# final location
make DESTDIR=$RPM_BUILD_ROOT install

# desktop file
desktop-file-install \
  --mode 644 \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-category X-Streamer \
  --delete-original \
  $RPM_BUILD_ROOT%{_datadir}/applications/flumotion-admin.desktop

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/flumotion

# install service files
install -d $RPM_BUILD_ROOT%{_unitdir}
install -m 644 \
        %{SOURCE1} \
        $RPM_BUILD_ROOT%{_unitdir}/flumotion.service

# create log and run and cache directory
install -d $RPM_BUILD_ROOT%{_var}/log/flumotion
install -d $RPM_BUILD_ROOT%{_var}/run/flumotion
install -d $RPM_BUILD_ROOT%{_var}/cache/flumotion

# Install the logrotate entry
%{__install} -m 0644 -D doc/redhat/flumotion.logrotate \
    %{buildroot}%{_sysconfdir}/logrotate.d/flumotion

%find_lang flumotion
# generic fedora font import transformations
# move fonts to corresponding subdirs if any
for fontpatt in OTF TTF TTC otf ttf ttc pcf pcf.gz bdf afm pfa pfb; do
    case "$fontpatt" in 
	pcf*|bdf*) type=bitmap;;
	tt*|TT*) type=ttf;;
	otf|OTF) type=otf;;
	afm*|pf*) type=type1;;
    esac
    find $RPM_BUILD_ROOT/usr/share/fonts -type f -name '*.'$fontpatt | while read i; do
	j=`echo "$i" | sed -e s,/usr/share/fonts/,/usr/share/fonts/$type/,`;
	install -Dm644 "$i" "$j";
	rm -f "$i";
	olddir=`dirname "$i"`;
	mv -f "$olddir"/{encodings.dir,fonts.{dir,scale,alias}} `dirname "$j"`/ 2>/dev/null ||:
	rmdir -p "$olddir" 2>/dev/null ||:
    done
done
# kill invalid catalogue links
if [ -d $RPM_BUILD_ROOT/etc/X11/fontpath.d ]; then
    find -L $RPM_BUILD_ROOT/etc/X11/fontpath.d -type l -print -delete ||:
    # relink catalogue
    find $RPM_BUILD_ROOT/usr/share/fonts -name fonts.dir | while read i; do
	pri=10;
	j=`echo $i | sed -e s,$RPM_BUILD_ROOT/usr/share/fonts/,,`; type=${j%%%%/*}; 
	pre_stem=${j##$type/}; stem=`dirname $pre_stem|sed -e s,/,-,g`;
	case "$type" in 
	    bitmap) pri=10;;
	    ttf|ttf) pri=50;;
	    type1) pri=40;;
	esac
	ln -s /usr/share/fonts/$j $RPM_BUILD_ROOT/etc/X11/fontpath.d/"$stem:pri=$pri"
    done ||:
fi

%pre
/usr/sbin/useradd -s /sbin/nologin \
        -r -d %{_var}/cache/flumotion -M \
        flumotion > /dev/null 2> /dev/null || :
# for old installs, we need to move the homedir
/usr/sbin/usermod -d %{_var}/cache/flumotion \
        flumotion > /dev/null 2> /dev/null || :

%post
PEM_FILE="%{_sysconfdir}/flumotion/default.pem"
if ! test -e ${PEM_FILE}
then
  sh %{_datadir}/flumotion/make-dummy-cert ${PEM_FILE}
  chown :flumotion ${PEM_FILE}
  chmod 640 ${PEM_FILE}
fi

# create a default planet config if no manager configs present
# the default login will be user/test
if ! test -e %{_sysconfdir}/flumotion/managers
then
  mkdir -p %{_sysconfdir}/flumotion/managers/default/flows
  cat > %{_sysconfdir}/flumotion/managers/default/planet.xml <<EOF
<planet>
 
  <manager>
    <!-- <debug>3</debug> -->
    <host>localhost</host>
<!--
    <port>7531</port>
    <transport>ssl</transport>
-->
    <!-- certificate path can be relative to $sysconfdir/flumotion,
         or absolute -->
<!--
    <certificate>default.pem</certificate>
-->
    <component name="manager-bouncer" type="htpasswdcrypt-bouncer">
      <property name="data"><![CDATA[
user:PSfNpHTkpTx1M
]]></property>
    </component>
  </manager>
 
</planet>
EOF
fi

# create a default worker config if no worker configs present
# the default login will be user/test
if ! test -e %{_sysconfdir}/flumotion/workers
then
  mkdir -p %{_sysconfdir}/flumotion/workers
  cat > %{_sysconfdir}/flumotion/workers/default.xml <<EOF
<worker>
 
  <!-- <debug>3</debug> -->

  <manager>
<!--
    <host>localhost</host>
    <port>7531</port>
-->
  </manager>

  <authentication type="plaintext">
    <username>user</username>
    <password>test</password>
  </authentication>

  <!-- <feederports>8600-8639</feederports> -->
 
</worker>
EOF

fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    rm -rf %{_var}/lock/flumotion*
    rm -rf %{_var}/run/flumotion*

    # clean out the cache/home dir too, without deleting it or the user
    rm -rf %{_var}/cache/flumotion/*
    rm -rf %{_var}/cache/flumotion/.[^.]*
fi

%files -f flumotion.lang
%doc ChangeLog COPYING README AUTHORS flumotion.doap
%doc doc/reference/html
%doc conf
%config(noreplace) %{_sysconfdir}/logrotate.d/flumotion
%{_bindir}/flumotion-manager
%{_bindir}/flumotion-worker
%{_bindir}/flumotion-admin
%{_bindir}/flumotion-admin-text
%{_bindir}/flumotion-command
%{_bindir}/flumotion-tester
%{_bindir}/flumotion-job
%{_bindir}/flumotion-inspect
%{_bindir}/flumotion-launch
%{_bindir}/flumotion-rrdmon
%{_bindir}/flumotion-nagios
%{_sbindir}/flumotion

%{_libdir}/flumotion
%{_libdir}/pkgconfig/flumotion.pc

%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*
%{_mandir}/man1/flumotion*.1*

%dir %{_datadir}/flumotion
%{_datadir}/flumotion/glade
%{_datadir}/flumotion/image
%{_datadir}/flumotion/make-dummy-cert
%{_datadir}/flumotion/*.xsl
%{_datadir}/flumotion/*.html
%{_datadir}/hal/fdi/policy/20thirdparty/91-flumotion-device-policy.fdi

%attr(750,root,flumotion) %{_sysconfdir}/flumotion
%attr(770,root,flumotion) %{_var}/run/flumotion
%attr(770,root,flumotion) %{_var}/log/flumotion
%attr(770,root,flumotion) %{_var}/cache/flumotion
%{_unitdir}/flumotion.service

%changelog
* Thu Apr 25 2013 Igor Vlasenko <viy@altlinux.ru> 0.10.0-alt1_6
- initial fc import

